summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/browser_window.h
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-30 21:09:24 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-30 21:09:24 +0000
commit0ec4898e0384bdcd499a9fb27d66d7e226788cef (patch)
treea155f8f483d01f87ec4e366bbbd836dfbe2641fa /chrome/browser/ui/browser_window.h
parentaf3594e07f3b8e43c547d5bab900cd15b23b0208 (diff)
downloadchromium_src-0ec4898e0384bdcd499a9fb27d66d7e226788cef.zip
chromium_src-0ec4898e0384bdcd499a9fb27d66d7e226788cef.tar.gz
chromium_src-0ec4898e0384bdcd499a9fb27d66d7e226788cef.tar.bz2
Replace WebUI::tab_contents() with web_contents() and switch all users to use web_contents.h instead of tab_contents.h. In a few cases some of these files used functions that needed a TabContents, so I switched them as well.
BUG=98716 TBR=joi Review URL: http://codereview.chromium.org/9003014 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@116051 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/browser_window.h')
-rw-r--r--chrome/browser/ui/browser_window.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/ui/browser_window.h b/chrome/browser/ui/browser_window.h
index 6e9d5df..5ff7fdc 100644
--- a/chrome/browser/ui/browser_window.h
+++ b/chrome/browser/ui/browser_window.h
@@ -361,10 +361,10 @@ class BrowserWindow {
// Construct a BrowserWindow implementation for the specified |browser|.
static BrowserWindow* CreateBrowserWindow(Browser* browser);
// Shows the avatar bubble inside |tab_contents|. The bubble is positioned
// relative to |rect|. |rect| should be in the |tab_contents| coordinate
// system.
- virtual void ShowAvatarBubble(TabContents* tab_contents,
+ virtual void ShowAvatarBubble(content::WebContents* web_contents,
const gfx::Rect& rect) = 0;
// Shows the avatar bubble on the window frame off of the avatar button.
@@ -361,10 +361,10 @@ class BrowserWindow {
// Construct a BrowserWindow implementation for the specified |browser|.
static BrowserWindow* CreateBrowserWindow(Browser* browser);
- // Shows the avatar bubble inside |tab_contents|. The bubble is positioned
- // relative to |rect|. |rect| should be in the |tab_contents| coordinate
+ // Shows the avatar bubble inside |web_contents|. The bubble is positioned
+ // relative to |rect|. |rect| should be in the |web_contents| coordinate
// system.